==> apache-opennlp_1.9.3.orig.tar.gz: apache-opennlp-1.9.3-src/opennlp-tools/src/test/java/opennlp/tools/util/featuregen/PosTaggerFeatureGeneratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.util.featuregen;

import java.util.ArrayList;
import java.util.List;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class PosTaggerFeatureGeneratorTest {

  private List<String> features;
  static String[] testSentence = new String[] {"This", "is", "an", "example", "sentence"};
  static String[] testTags = new String[] {"DT", "VBZ", "DT", "NN", "NN"};

  @Before
  public void setUp() throws Exception {
    features = new ArrayList<>();
  }

  @Test
  public void testBegin() {

    final int testTokenIndex = 0;

    AdaptiveFeatureGenerator generator = new PosTaggerFeatureGenerator();

    generator.createFeatures(features, testSentence, testTokenIndex, testTags);

    Assert.assertEquals(0, features.size());
  }

  @Test
  public void testNext() {

    final int testTokenIndex = 1;

    AdaptiveFeatureGenerator generator = new PosTaggerFeatureGenerator();

    generator.createFeatures(features, testSentence, testTokenIndex, testTags);

    Assert.assertEquals(1, features.size());
    Assert.assertEquals("t=DT", features.get(0));
  }

  @Test
  public void testMiddle() {

    final int testTokenIndex = 3;

    AdaptiveFeatureGenerator generator = new PosTaggerFeatureGenerator();

    generator.createFeatures(features, testSentence, testTokenIndex, testTags);

    Assert.assertEquals(2, features.size());
    Assert.assertEquals("t=DT", features.get(0));
    Assert.assertEquals("t2=VBZ,DT", features.get(1));
  }
}

==> apache-opennlp_2.1.0.orig.tar.gz: apache-opennlp-2.1.0-src/opennlp-tools/src/test/java/opennlp/tools/util/featuregen/PosTaggerFeatureGeneratorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.util.featuregen;

import java.util.ArrayList;
import java.util.List;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

public class PosTaggerFeatureGeneratorTest {

  private List<String> features;
  static String[] testSentence = new String[] {"This", "is", "an", "example", "sentence"};
  static String[] testTags = new String[] {"DT", "VBZ", "DT", "NN", "NN"};

  @BeforeEach
  void setUp()  {
    features = new ArrayList<>();
  }

  @Test
  void testBegin() {

    final int testTokenIndex = 0;

    AdaptiveFeatureGenerator generator = new PosTaggerFeatureGenerator();

    generator.createFeatures(features, testSentence, testTokenIndex, testTags);

    Assertions.assertEquals(0, features.size());
  }

  @Test
  void testNext() {

    final int testTokenIndex = 1;

    AdaptiveFeatureGenerator generator = new PosTaggerFeatureGenerator();

    generator.createFeatures(features, testSentence, testTokenIndex, testTags);

    Assertions.assertEquals(1, features.size());
    Assertions.assertEquals("t=DT", features.get(0));
  }

  @Test
  void testMiddle() {

    final int testTokenIndex = 3;

    AdaptiveFeatureGenerator generator = new PosTaggerFeatureGenerator();

    generator.createFeatures(features, testSentence, testTokenIndex, testTags);

    Assertions.assertEquals(2, features.size());
    Assertions.assertEquals("t=DT", features.get(0));
    Assertions.assertEquals("t2=VBZ,DT", features.get(1));
  }
}
